Support
=======

For support, please contact our support team via e-mail at
`support@recapturedocs.com <mailto:support@recapturedocs.com>`_. We strive to
answer all e-mails within 24 hours and often answer in the same hour.
